@@ -31,8 +31,7 @@ import (
 // The Resume trait can be used to manage and configure resume strategies.
 //
 // This feature is meant to allow quick resume of processing by Camel K instances after they have been restarted. This
-// is an experimental implementation based on the support available on Camel Core:
-// https://camel.apache.org/components/next/eips/resume-strategies.html.
+// is an experimental implementation based on the support available on Camel Core resume strategies.
 //
 // The Resume trait is disabled by default.
 //
@@ -91,7 +90,10 @@ func (r *resumeTrait) Configure(environment *trait.Environment) (bool, error) {
 			return false, err
 		}
 
-		meta := metadata.ExtractAll(environment.CamelCatalog, sources)
+		meta, err := metadata.ExtractAll(environment.CamelCatalog, sources)
+		if err != nil {
+			return false, err
+		}
 
 		for _, endpoint := range meta.FromURIs {
 			log.Infof("Processing component %s", endpoint)
