@@ -37,28 +37,30 @@ const (
 	// v1.Build,          v1.Integration
 	// v1.IntegrationKit, v1.IntegrationPlatform
 	// v1alpha1.Kamelet,  v1alpha1.KameletBinding
-	ExpCrds = 6
+	ExpectedCRDs = 6
 
-	// camel-k-operator, 			 camel-k-operator-events,
-	// camel-k-operator-knative, 	 camel-k-operator-leases,
+	// camel-k-operator,             camel-k-operator-events,
+	// camel-k-operator-knative,     camel-k-operator-leases,
 	// camel-k-operator-podmonitors, camel-k-operator-strimzi,
 	// camel-k-operator-keda
-	ExpKubePromoteRoles = 7
+	ExpectedKubePromoteRoles = 7
 
 	// camel-k-edit
 	// camel-k-operator-custom-resource-definitions
 	// camel-k-operator-bind-addressable-resolver
 	// camel-k-operator-local-registry
-	ExpKubeClusterRoles = 4
+	ExpectedKubeClusterRoles = 4
 
 	// camel-k-operator-openshift
-	ExpOSPromoteRoles = 1
+	ExpectedOSPromoteRoles = 1
 
 	// camel-k-operator-console-openshift
-	ExpOSClusterRoles = 1
+	ExpectedOSClusterRoles = 1
 )
 
-func ExecMake(t *testing.T, command *exec.Cmd) {
+func ExpectExecSucceed(t *testing.T, command *exec.Cmd) {
+	t.Helper()
+
 	var cmdOut strings.Builder
 	var cmdErr strings.Builder
 
@@ -72,14 +74,16 @@ func ExecMake(t *testing.T, command *exec.Cmd) {
 	session, err := gexec.Start(command, &cmdOut, &cmdErr)
 	session.Wait()
 	Eventually(session).Should(gexec.Exit(0))
-	assert.Nil(t, err)
+	assert.NoError(t, err)
 	assert.NotContains(t, strings.ToUpper(cmdErr.String()), "ERROR")
 }
 
 //
-// Expect a make error with an exit code of 1
+// Expect a command error with an exit code of 1
 //
-func ExecMakeError(t *testing.T, command *exec.Cmd) {
+func ExpectExecError(t *testing.T, command *exec.Cmd) {
+	t.Helper()
+
 	var cmdOut strings.Builder
 	var cmdErr strings.Builder
 
@@ -93,7 +97,7 @@ func ExecMakeError(t *testing.T, command *exec.Cmd) {
 	session, err := gexec.Start(command, &cmdOut, &cmdErr)
 	session.Wait()
 	Eventually(session).ShouldNot(gexec.Exit(0))
-	assert.Nil(t, err)
+	assert.NoError(t, err)
 	assert.Contains(t, strings.ToUpper(cmdErr.String()), "ERROR")
 }
 
