@@ -27,12 +27,16 @@ import (
 	"os"
 	"testing"
 
+	corev1 "k8s.io/api/core/v1"
+
 	. "github.com/apache/camel-k/e2e/support"
+	testutil "github.com/apache/camel-k/e2e/support/util"
 	. "github.com/onsi/gomega"
 )
 
-func TestBasicOperator(t *testing.T) {
-	os.Setenv("MAKE_DIR", "../../../../install")
+func TestOperatorBasic(t *testing.T) {
+	makeDir := testutil.MakeTempCopyDir(t, "../../../../install")
+	os.Setenv("CAMEL_K_TEST_MAKE_DIR", makeDir)
 
 	// Ensure no CRDs are already installed
 	UninstallAll()
@@ -41,16 +45,26 @@ func TestBasicOperator(t *testing.T) {
 	defer Cleanup()
 
 	WithNewTestNamespace(t, func(ns string) {
-		ExecMake(t, Make("setup-cluster", fmt.Sprintf("NAMESPACE=%s", ns)))
-		ExecMake(t, Make("setup", fmt.Sprintf("NAMESPACE=%s", ns)))
-		ExecMake(t, Make("operator", fmt.Sprintf("NAMESPACE=%s", ns)))
+		namespaceArg := fmt.Sprintf("NAMESPACE=%s", ns)
+		ExpectExecSucceed(t, Make("setup-cluster", namespaceArg))
+		ExpectExecSucceed(t, Make("setup", namespaceArg))
+		// Skip default kamelets installation for faster test runs
+		ExpectExecSucceed(t, Make("operator",
+			namespaceArg,
+			"INSTALL_DEFAULT_KAMELETS=false"))
+
+		// Refresh the test client to account for the newly installed CRDs
+		SyncClient()
 
 		Eventually(OperatorPod(ns)).ShouldNot(BeNil())
+		Eventually(OperatorPodPhase(ns), TestTimeoutMedium).Should(Equal(corev1.PodRunning))
+		Eventually(Platform(ns)).ShouldNot(BeNil())
 	})
 }
 
-func TestAlternativeImageOperator(t *testing.T) {
-	os.Setenv("MAKE_DIR", "../../../../install")
+func TestOperatorAlternativeImage(t *testing.T) {
+	makeDir := testutil.MakeTempCopyDir(t, "../../../../install")
+	os.Setenv("CAMEL_K_TEST_MAKE_DIR", makeDir)
 
 	// Ensure no CRDs are already installed
 	UninstallAll()
@@ -59,20 +73,29 @@ func TestAlternativeImageOperator(t *testing.T) {
 	defer Cleanup()
 
 	WithNewTestNamespace(t, func(ns string) {
+		namespaceArg := fmt.Sprintf("NAMESPACE=%s", ns)
+		ExpectExecSucceed(t, Make("setup-cluster", namespaceArg))
+		ExpectExecSucceed(t, Make("setup", namespaceArg))
 
-		ExecMake(t, Make("setup-cluster", fmt.Sprintf("NAMESPACE=%s", ns)))
-		ExecMake(t, Make("setup", fmt.Sprintf("NAMESPACE=%s", ns)))
-
+		// Skip default kamelets installation for faster test runs
 		newImage := "quay.io/kameltest/kamel-operator"
 		newTag := "1.1.1"
-		ExecMake(t, Make("operator", fmt.Sprintf("CUSTOM_IMAGE=%s", newImage), fmt.Sprintf("CUSTOM_VERSION=%s", newTag), fmt.Sprintf("NAMESPACE=%s", ns)))
+		ExpectExecSucceed(t, Make("operator",
+			fmt.Sprintf("CUSTOM_IMAGE=%s", newImage),
+			fmt.Sprintf("CUSTOM_VERSION=%s", newTag),
+			namespaceArg,
+			"INSTALL_DEFAULT_KAMELETS=false"))
+
+		// Refresh the test client to account for the newly installed CRDs
+		SyncClient()
 
 		Eventually(OperatorImage(ns)).Should(Equal(fmt.Sprintf("%s:%s", newImage, newTag)))
 	})
 }
 
-func TestGlobalOperator(t *testing.T) {
-	os.Setenv("MAKE_DIR", "../../../../install")
+func TestOperatorGlobal(t *testing.T) {
+	makeDir := testutil.MakeTempCopyDir(t, "../../../../install")
+	os.Setenv("CAMEL_K_TEST_MAKE_DIR", makeDir)
 
 	// Ensure no CRDs are already installed
 	UninstallAll()
@@ -81,13 +104,22 @@ func TestGlobalOperator(t *testing.T) {
 	defer Cleanup()
 
 	WithNewTestNamespace(t, func(ns string) {
-		ExecMake(t, Make("setup-cluster", fmt.Sprintf("NAMESPACE=%s", ns)))
-		ExecMake(t, Make("setup", fmt.Sprintf("NAMESPACE=%s", ns), "GLOBAL=true"))
+		namespaceArg := fmt.Sprintf("NAMESPACE=%s", ns)
+		ExpectExecSucceed(t, Make("setup-cluster", namespaceArg))
+		ExpectExecSucceed(t, Make("setup", namespaceArg, "GLOBAL=true"))
 
-		ExecMake(t, Make("operator", fmt.Sprintf("NAMESPACE=%s", ns), "GLOBAL=true"))
+		// Skip default kamelets installation for faster test runs
+		ExpectExecSucceed(t, Make("operator",
+			namespaceArg,
+			"GLOBAL=true",
+			"INSTALL_DEFAULT_KAMELETS=false"))
+
+		// Refresh the test client to account for the newly installed CRDs
+		SyncClient()
 
 		podFunc := OperatorPod(ns)
-		Eventually(podFunc).Should(Not(BeNil()))
+		Eventually(podFunc).ShouldNot(BeNil())
+		Eventually(OperatorPodPhase(ns), TestTimeoutMedium).Should(Equal(corev1.PodRunning))
 		pod := podFunc()
 
 		containers := pod.Spec.Containers
@@ -105,5 +137,7 @@ func TestGlobalOperator(t *testing.T) {
 			}
 		}
 		Expect(found).To(BeTrue())
+
+		Eventually(Platform(ns)).ShouldNot(BeNil())
 	})
 }
