@@ -28,11 +28,13 @@ import (
 	"testing"
 
 	. "github.com/apache/camel-k/e2e/support"
+	testutil "github.com/apache/camel-k/e2e/support/util"
 	. "github.com/onsi/gomega"
 )
 
-func TestBasicSetup(t *testing.T) {
-	os.Setenv("MAKE_DIR", "../../../../install")
+func TestSetupBasic(t *testing.T) {
+	makeDir := testutil.MakeTempCopyDir(t, "../../../../install")
+	os.Setenv("CAMEL_K_TEST_MAKE_DIR", makeDir)
 
 	// Ensure no CRDs are already installed
 	UninstallAll()
@@ -41,18 +43,19 @@ func TestBasicSetup(t *testing.T) {
 	defer Cleanup()
 
 	WithNewTestNamespace(t, func(ns string) {
-		ExecMake(t, Make("setup-cluster", fmt.Sprintf("NAMESPACE=%s", ns)))
-		Eventually(CRDs()).Should(HaveLen(ExpCrds))
+		namespaceArg := fmt.Sprintf("NAMESPACE=%s", ns)
+		ExpectExecSucceed(t, Make("setup-cluster", namespaceArg))
+		Eventually(CRDs()).Should(HaveLen(ExpectedCRDs))
 
-		ExecMake(t, Make("setup", fmt.Sprintf("NAMESPACE=%s", ns)))
+		ExpectExecSucceed(t, Make("setup", namespaceArg))
 
-		kroles := ExpKubePromoteRoles
-		osroles := kroles + ExpOSPromoteRoles
-		Eventually(Role(ns)).Should(Or(HaveLen(kroles), HaveLen(osroles)))
+		kpRoles := ExpectedKubePromoteRoles
+		opRoles := kpRoles + ExpectedOSPromoteRoles
+		Eventually(Role(ns)).Should(Or(HaveLen(kpRoles), HaveLen(opRoles)))
 
-		kcroles := ExpKubeClusterRoles
-		oscroles := kcroles + ExpOSClusterRoles
-		Eventually(ClusterRole()).Should(Or(HaveLen(kcroles), HaveLen(oscroles)))
+		kcRoles := ExpectedKubeClusterRoles
+		ocRoles := kcRoles + ExpectedOSClusterRoles
+		Eventually(ClusterRole()).Should(Or(HaveLen(kcRoles), HaveLen(ocRoles)))
 
 		// Tidy up to ensure next test works
 		Expect(Kamel("uninstall", "-n", ns).Execute()).To(Succeed())
@@ -60,8 +63,9 @@ func TestBasicSetup(t *testing.T) {
 
 }
 
-func TestGlobalSetup(t *testing.T) {
-	os.Setenv("MAKE_DIR", "../../../../install")
+func TestSetupGlobal(t *testing.T) {
+	makeDir := testutil.MakeTempCopyDir(t, "../../../../install")
+	os.Setenv("CAMEL_K_TEST_MAKE_DIR", makeDir)
 
 	// Ensure no CRDs are already installed
 	UninstallAll()
@@ -70,15 +74,16 @@ func TestGlobalSetup(t *testing.T) {
 	defer Cleanup()
 
 	WithNewTestNamespace(t, func(ns string) {
-		ExecMake(t, Make("setup-cluster", fmt.Sprintf("NAMESPACE=%s", ns)))
-		Eventually(CRDs()).Should(HaveLen(ExpCrds))
+		namespaceArg := fmt.Sprintf("NAMESPACE=%s", ns)
+		ExpectExecSucceed(t, Make("setup-cluster", namespaceArg))
+		Eventually(CRDs()).Should(HaveLen(ExpectedCRDs))
 
-		ExecMake(t, Make("setup", "GLOBAL=true", fmt.Sprintf("NAMESPACE=%s", ns)))
+		ExpectExecSucceed(t, Make("setup", "GLOBAL=true", namespaceArg))
 
 		Eventually(Role(ns)).Should(HaveLen(0))
 
-		kcroles := ExpKubeClusterRoles + ExpKubePromoteRoles
-		oscroles := kcroles + ExpOSClusterRoles + ExpOSPromoteRoles
-		Eventually(ClusterRole()).Should(Or(HaveLen(kcroles), HaveLen(oscroles)))
+		kcpRoles := ExpectedKubeClusterRoles + ExpectedKubePromoteRoles
+		ocpRoles := kcpRoles + ExpectedOSClusterRoles + ExpectedOSPromoteRoles
+		Eventually(ClusterRole()).Should(Or(HaveLen(kcpRoles), HaveLen(ocpRoles)))
 	})
 }
