@@ -1535,6 +1535,18 @@ func BuildPhase(ns, name string) func() v1.BuildPhase {
 	}
 }
 
+func BuildsRunning(predicates ...func() v1.BuildPhase) func() int {
+	return func() int {
+		runningBuilds := 0
+		for _, predicate := range predicates {
+			if predicate() == v1.BuildPhaseRunning {
+				runningBuilds++
+			}
+		}
+		return runningBuilds
+	}
+}
+
 func HasPlatform(ns string) func() bool {
 	return func() bool {
 		lst := v1.NewIntegrationPlatformList()
@@ -1608,6 +1620,16 @@ func PlatformPhase(ns string) func() v1.IntegrationPlatformPhase {
 	}
 }
 
+func PlatformHas(ns string, predicate func(pl *v1.IntegrationPlatform) bool) func() bool {
+	return func() bool {
+		pl := Platform(ns)()
+		if pl == nil {
+			return false
+		}
+		return predicate(pl)
+	}
+}
+
 func PlatformCondition(
 	ns string,
 	conditionType v1.IntegrationPlatformConditionType,
@@ -2198,7 +2220,7 @@ func Pods(ns string) func() []corev1.Pod {
 
 func WithNewTestNamespace(t *testing.T, doRun func(string)) {
 	setTestLocus(t)
-	ns := newTestNamespace(false)
+	ns := NewTestNamespace(false)
 	defer deleteTestNamespace(t, ns)
 	defer userCleanup(t)
 
@@ -2220,7 +2242,7 @@ func WithGlobalOperatorNamespace(t *testing.T, test func(string)) {
 
 func WithNewTestNamespaceWithKnativeBroker(t *testing.T, doRun func(string)) {
 	setTestLocus(t)
-	ns := newTestNamespace(true)
+	ns := NewTestNamespace(true)
 	defer deleteTestNamespace(t, ns)
 	defer deleteKnativeBroker(ns)
 	defer userCleanup(t)
@@ -2248,11 +2270,7 @@ func invokeUserTestCode(t *testing.T, ns string, doRun func(string)) {
 	globalTest := os.Getenv("CAMEL_K_FORCE_GLOBAL_TEST") == "true"
 
 	defer func(isGlobal bool) {
-		if t.Failed() {
-			if err := util.Dump(TestContext, TestClient(), ns, t); err != nil {
-				t.Logf("Error while dumping namespace %s: %v\n", ns, err)
-			}
-		}
+		DumpNamespace(t, ns)
 
 		// Try to clean up namespace
 		if !isGlobal && HasPlatform(ns)() {
@@ -2363,7 +2381,26 @@ func testNamespaceExists(ns string) (bool, error) {
 	return true, nil
 }
 
-func newTestNamespace(injectKnativeBroker bool) ctrl.Object {
+func DumpNamespace(t *testing.T, ns string) {
+	if t.Failed() {
+		if err := util.Dump(TestContext, TestClient(), ns, t); err != nil {
+			t.Logf("Error while dumping namespace %s: %v\n", ns, err)
+		}
+	}
+}
+
+func DeleteNamespace(t *testing.T, ns string) error {
+	nsObj, err := TestClient().CoreV1().Namespaces().Get(TestContext, ns, metav1.GetOptions{})
+	if err != nil {
+		return err
+	}
+
+	deleteTestNamespace(t, nsObj)
+
+	return nil
+}
+
+func NewTestNamespace(injectKnativeBroker bool) ctrl.Object {
 	brokerLabel := "eventing.knative.dev/injection"
 	name := os.Getenv("CAMEL_K_TEST_NS")
 	if name == "" {
