@@ -25,10 +25,14 @@ package support
 import (
 	. "github.com/onsi/gomega"
 	. "github.com/onsi/gomega/gstruct"
-
 	"github.com/onsi/gomega/types"
+	"os"
 )
 
+func init() {
+
+}
+
 func EqualP(expected interface{}) types.GomegaMatcher {
 	return PointTo(Equal(expected))
 }
@@ -36,3 +40,12 @@ func EqualP(expected interface{}) types.GomegaMatcher {
 func MatchFieldsP(options Options, fields Fields) types.GomegaMatcher {
 	return PointTo(MatchFields(options, fields))
 }
+
+func GetEnvOrDefault(key string, deflt string) string {
+	env, exists := os.LookupEnv(key)
+	if exists {
+		return env
+	} else {
+		return deflt
+	}
+}
