@@ -62,6 +62,33 @@ func NewCamelCatalogList() CamelCatalogList {
 	}
 }
 
+// GetRuntimeVersion returns the Camel K runtime version of the catalog.
+func (c *CamelCatalogSpec) GetRuntimeVersion() string {
+	return c.Runtime.Version
+}
+
+// GetCamelVersion returns the Camel version the runtime is based on.
+func (c *CamelCatalogSpec) GetCamelVersion() string {
+	return c.Runtime.Metadata["camel.version"]
+}
+
+// GetCamelQuarkusVersion returns the Camel Quarkus version the runtime is based on.
+func (c *CamelCatalogSpec) GetCamelQuarkusVersion() string {
+	return c.Runtime.Metadata["camel-quarkus.version"]
+}
+
+// GetQuarkusVersion returns the Quarkus version the runtime is based on.
+func (c *CamelCatalogSpec) GetQuarkusVersion() string {
+	return c.Runtime.Metadata["quarkus.version"]
+}
+
+// HasCapability checks if the given capability is present in the catalog.
+func (c *CamelCatalogSpec) HasCapability(capability string) bool {
+	_, ok := c.Runtime.Capabilities[capability]
+
+	return ok
+}
+
 // GetDependencyID returns a Camel K recognizable maven dependency for the artifact
 func (in *CamelArtifact) GetDependencyID() string {
 	switch {
@@ -74,20 +101,20 @@ func (in *CamelArtifact) GetDependencyID() string {
 	}
 }
 
-func (in *CamelArtifact) GetConsumerDependencyIDs(schemeID string) (deps []string) {
+func (in *CamelArtifact) GetConsumerDependencyIDs(schemeID string) []string {
 	return in.getDependencyIDs(schemeID, consumerScheme)
 }
 
-func (in *CamelArtifact) GetProducerDependencyIDs(schemeID string) (deps []string) {
+func (in *CamelArtifact) GetProducerDependencyIDs(schemeID string) []string {
 	return in.getDependencyIDs(schemeID, producerScheme)
 }
 
-func (in *CamelArtifact) getDependencyIDs(schemeID string, scope func(CamelScheme) CamelSchemeScope) (deps []string) {
+func (in *CamelArtifact) getDependencyIDs(schemeID string, scope func(CamelScheme) CamelSchemeScope) []string {
 	ads := in.getDependencies(schemeID, scope)
 	if ads == nil {
-		return deps
+		return nil
 	}
-	deps = make([]string, 0, len(ads))
+	deps := make([]string, 0, len(ads))
 	for _, ad := range ads {
 		deps = append(deps, ad.GetDependencyID())
 	}
