@@ -294,6 +294,8 @@ const (
 	CapabilityCircuitBreaker = "circuit-breaker"
 	// CapabilityTracing defines the tracing (opentracing) capability
 	CapabilityTracing = "tracing"
+	// CapabilityTelemetry defines the telemetry (opentelemetry) capability
+	CapabilityTelemetry = "telemetry"
 	// CapabilityMaster defines the master capability
 	CapabilityMaster = "master"
 	// CapabilityResumeKafka defines the resume capability
@@ -302,8 +304,10 @@ const (
 	CapabilityAwsSecretsManager = "aws-secrets-manager"
 	// CapabilityGcpSecretManager defines the gcp secret manager capability
 	CapabilityGcpSecretManager = "gcp-secret-manager"
-	// CapabilityGcpSecretManager defines the azure key vault capability
+	// CapabilityAzureKeyVault defines the azure key vault capability
 	CapabilityAzureKeyVault = "azure-key-vault"
+	// CapabilityHashicorpVault defines the Hashicorp Vault capability
+	CapabilityHashicorpVault = "hashicorp-vault"
 )
 
 // +kubebuilder:object:generate=false
@@ -422,6 +426,8 @@ const (
 	LanguageYaml Language = "yaml"
 	// LanguageKamelet used for Kamelets
 	LanguageKamelet Language = "kamelet"
+	// LanguageJavaShell used for Java Shell
+	LanguageJavaShell Language = "jsh"
 )
 
 // Languages is the list of all supported languages
@@ -433,4 +439,5 @@ var Languages = []Language{
 	LanguageKotlin,
 	LanguageYaml,
 	LanguageKamelet,
+	LanguageJavaShell,
 }
