@@ -126,6 +126,8 @@ type IntegrationPlatformBuildSpec struct {
 	Maven MavenSpec `json:"maven,omitempty"`
 	// Generic options that can used by each publish strategy
 	PublishStrategyOptions map[string]string `json:"PublishStrategyOptions,omitempty"`
+	// the maximum amount of parallel running builds started by this operator instance
+	MaxRunningBuilds int32 `json:"maxRunningBuilds,omitempty"`
 }
 
 // IntegrationPlatformKameletSpec define the behavior for all the Kamelets controller by the IntegrationPlatform
