@@ -192,16 +192,6 @@ func ValidKameletProperties(kamelet *Kamelet) bool {
 	return true
 }
 
-func ValidKameletTemplate(kamelet *Kamelet) bool {
-	if kamelet == nil {
-		return true
-	}
-	if kamelet.Spec.Template != nil && kamelet.Spec.Flow != nil {
-		return false
-	}
-	return true
-}
-
 // NewKamelet creates a new kamelet
 func NewKamelet(namespace string, name string) Kamelet {
 	return Kamelet{
