@@ -43,29 +43,27 @@ func newCmdBind(rootCmdOptions *RootCmdOptions) (*cobra.Command, *bindCmdOptions
 		RootCmdOptions: rootCmdOptions,
 	}
 	cmd := cobra.Command{
-		Use:     "bind [source] [sink] ...",
-		Short:   "Bind Kubernetes resources, such as Kamelets, in an integration flow. Endpoints are expected in the format \"[[apigroup/]version:]kind:[namespace/]name\" or plain Camel URIs.",
-		PreRunE: decode(&options),
-		RunE: func(cmd *cobra.Command, args []string) error {
-			if err := options.validate(cmd, args); err != nil {
-				return err
-			}
-			if err := options.run(cmd, args); err != nil {
-				fmt.Fprintln(cmd.OutOrStdout(), err.Error())
-			}
-
-			return nil
-		},
+		Use:               "bind [source] [sink] ...",
+		Short:             "Bind Kubernetes resources, such as Kamelets, in an integration flow.",
+		Long:              "Bind Kubernetes resources, such as Kamelets, in an integration flow. Endpoints are expected in the format \"[[apigroup/]version:]kind:[namespace/]name\" or plain Camel URIs.",
+		PersistentPreRunE: decode(&options),
+		PreRunE:           options.preRunE,
+		RunE:              options.runE,
+		Annotations:       make(map[string]string),
 	}
 
 	cmd.Flags().StringArrayP("connect", "c", nil, "A ServiceBinding or Provisioned Service that the integration should bind to, specified as [[apigroup/]version:]kind:[namespace/]name")
 	cmd.Flags().String("error-handler", "", `Add error handler (none|log|sink:<endpoint>). Sink endpoints are expected in the format "[[apigroup/]version:]kind:[namespace/]name", plain Camel URIs or Kamelet name.`)
 	cmd.Flags().String("name", "", "Name for the binding")
 	cmd.Flags().StringP("output", "o", "", "Output format. One of: json|yaml")
-	cmd.Flags().StringArrayP("property", "p", nil, `Add a binding property in the form of "source.<key>=<value>", "sink.<key>=<value>", "error-handler.<key>=<value>" or "step-<n>.<key>=<value>"`)
+	cmd.Flags().StringArrayP("property", "p", nil, `Add a binding property in the form of "source.<key>=<value>", "sink.<key>=<value>", "error-handler.<key>=<value>" or "step-<n>.<key>=<value> where <n> is the step order starting from 1"`)
 	cmd.Flags().Bool("skip-checks", false, "Do not verify the binding for compliance with Kamelets and other Kubernetes resources")
 	cmd.Flags().StringArray("step", nil, `Add binding steps as Kubernetes resources. Endpoints are expected in the format "[[apigroup/]version:]kind:[namespace/]name", plain Camel URIs or Kamelet name.`)
 	cmd.Flags().StringArrayP("trait", "t", nil, `Add a trait to the corresponding Integration.`)
+	cmd.Flags().StringP("operator-id", "x", "camel-k", "Operator id selected to manage this Kamelet binding.")
+	cmd.Flags().StringArray("annotation", nil, "Add an annotation to the Kamelet binding. E.g. \"--annotation my.company=hello\"")
+	cmd.Flags().Bool("force", false, "Force creation of Kamelet binding regardless of potential misconfiguration.")
+	cmd.Flags().String("service-account", "", "The SA to use to run this binding")
 
 	return &cmd, &options
 }
@@ -79,14 +77,37 @@ const (
 
 type bindCmdOptions struct {
 	*RootCmdOptions
-	ErrorHandler string   `mapstructure:"error-handler" yaml:",omitempty"`
-	Name         string   `mapstructure:"name" yaml:",omitempty"`
-	Connects     []string `mapstructure:"connects" yaml:",omitempty"`
-	OutputFormat string   `mapstructure:"output" yaml:",omitempty"`
-	Properties   []string `mapstructure:"properties" yaml:",omitempty"`
-	SkipChecks   bool     `mapstructure:"skip-checks" yaml:",omitempty"`
-	Steps        []string `mapstructure:"steps" yaml:",omitempty"`
-	Traits       []string `mapstructure:"traits" yaml:",omitempty"`
+	ErrorHandler   string   `mapstructure:"error-handler" yaml:",omitempty"`
+	Name           string   `mapstructure:"name" yaml:",omitempty"`
+	Connects       []string `mapstructure:"connects" yaml:",omitempty"`
+	OutputFormat   string   `mapstructure:"output" yaml:",omitempty"`
+	Properties     []string `mapstructure:"properties" yaml:",omitempty"`
+	SkipChecks     bool     `mapstructure:"skip-checks" yaml:",omitempty"`
+	Steps          []string `mapstructure:"steps" yaml:",omitempty"`
+	Traits         []string `mapstructure:"traits" yaml:",omitempty"`
+	OperatorID     string   `mapstructure:"operator-id" yaml:",omitempty"`
+	Annotations    []string `mapstructure:"annotations" yaml:",omitempty"`
+	Force          bool     `mapstructure:"force" yaml:",omitempty"`
+	ServiceAccount string   `mapstructure:"service-account" yaml:",omitempty"`
+}
+
+func (o *bindCmdOptions) preRunE(cmd *cobra.Command, args []string) error {
+	if o.OutputFormat != "" {
+		// let the command work in offline mode
+		cmd.Annotations[offlineCommandLabel] = "true"
+	}
+	return o.RootCmdOptions.preRun(cmd, args)
+}
+
+func (o *bindCmdOptions) runE(cmd *cobra.Command, args []string) error {
+	if err := o.validate(cmd, args); err != nil {
+		return err
+	}
+	if err := o.run(cmd, args); err != nil {
+		fmt.Fprintln(cmd.OutOrStdout(), err.Error())
+	}
+
+	return nil
 }
 
 func (o *bindCmdOptions) validate(cmd *cobra.Command, args []string) error {
@@ -96,6 +117,17 @@ func (o *bindCmdOptions) validate(cmd *cobra.Command, args []string) error {
 		return errors.New("source or sink arguments are missing")
 	}
 
+	if o.OperatorID == "" {
+		return fmt.Errorf("cannot use empty operator id")
+	}
+
+	for _, annotation := range o.Annotations {
+		parts := strings.SplitN(annotation, "=", 2)
+		if len(parts) != 2 {
+			return fmt.Errorf(`invalid annotation specification %s. Expected "<annotationkey>=<annotationvalue>"`, annotation)
+		}
+	}
+
 	for _, p := range o.Properties {
 		if _, _, _, err := o.parseProperty(p); err != nil {
 			return err
@@ -145,7 +177,6 @@ func (o *bindCmdOptions) run(cmd *cobra.Command, args []string) error {
 	if err != nil {
 		return err
 	}
-	catalog := trait.NewCatalog(client)
 
 	source, err := o.decode(args[0], sourceKey)
 	if err != nil {
@@ -181,7 +212,8 @@ func (o *bindCmdOptions) run(cmd *cobra.Command, args []string) error {
 	if len(o.Steps) > 0 {
 		binding.Spec.Steps = make([]v1alpha1.Endpoint, 0)
 		for idx, stepDesc := range o.Steps {
-			stepKey := fmt.Sprintf("%s%d", stepKeyPrefix, idx)
+			stepIndex := idx + 1
+			stepKey := fmt.Sprintf("%s%d", stepKeyPrefix, stepIndex)
 			step, err := o.decode(stepDesc, stepKey)
 			if err != nil {
 				return err
@@ -197,28 +229,50 @@ func (o *bindCmdOptions) run(cmd *cobra.Command, args []string) error {
 		if binding.Spec.Integration == nil {
 			binding.Spec.Integration = &v1.IntegrationSpec{}
 		}
-		traits, err := configureTraits(o.Traits, catalog)
-		if err != nil {
+		catalog := trait.NewCatalog(client)
+		if err := configureTraits(o.Traits, &binding.Spec.Integration.Traits, catalog); err != nil {
 			return err
 		}
-		binding.Spec.Integration.Traits = traits
+	}
+
+	if binding.Annotations == nil {
+		binding.Annotations = make(map[string]string)
+	}
+
+	if o.ServiceAccount != "" {
+		binding.Spec.ServiceAccountName = o.ServiceAccount
+	}
+
+	if !isOfflineCommand(cmd) && o.OperatorID != "" {
+		if err := verifyOperatorID(o.Context, client, o.OperatorID); err != nil {
+			if o.Force {
+				o.PrintfVerboseErrf(cmd, "%s, use --force option or make sure to use a proper operator id", err.Error())
+			} else {
+				return err
+			}
+		}
+	}
+
+	// --operator-id={id} is a syntax sugar for '--annotation camel.apache.org/operator.id={id}'
+	binding.SetOperatorID(strings.TrimSpace(o.OperatorID))
+
+	for _, annotation := range o.Annotations {
+		parts := strings.SplitN(annotation, "=", 2)
+		if len(parts) == 2 {
+			binding.Annotations[parts[0]] = parts[1]
+		}
 	}
 
 	if o.OutputFormat != "" {
-		return showOutput(cmd, &binding, o.OutputFormat, client.GetScheme())
+		return showKameletBindingOutput(cmd, &binding, o.OutputFormat, client.GetScheme())
 	}
 
-	existed := false
-	err = client.Create(o.Context, &binding)
-	if err != nil && k8serrors.IsAlreadyExists(err) {
-		existed = true
-		err = kubernetes.ReplaceResource(o.Context, client, &binding)
-	}
+	replaced, err := kubernetes.ReplaceResource(o.Context, client, &binding)
 	if err != nil {
 		return err
 	}
 
-	if !existed {
+	if !replaced {
 		fmt.Fprintln(cmd.OutOrStdout(), `kamelet binding "`+name+`" created`)
 	} else {
 		fmt.Fprintln(cmd.OutOrStdout(), `kamelet binding "`+name+`" updated`)
@@ -226,7 +280,7 @@ func (o *bindCmdOptions) run(cmd *cobra.Command, args []string) error {
 	return nil
 }
 
-func showOutput(cmd *cobra.Command, binding *v1alpha1.KameletBinding, outputFormat string, scheme runtime.ObjectTyper) error {
+func showKameletBindingOutput(cmd *cobra.Command, binding *v1alpha1.KameletBinding, outputFormat string, scheme runtime.ObjectTyper) error {
 	printer := printers.NewTypeSetter(scheme)
 	printer.Delegate = &kubernetes.CLIPrinter{
 		Format: outputFormat,
