@@ -41,12 +41,12 @@ func newDescribePlatformCmd(rootCmdOptions *RootCmdOptions) (*cobra.Command, *de
 		Short:   "Describe an Integration Platform",
 		Long:    `Describe an Integration Platform.`,
 		PreRunE: decode(&options),
-		RunE: func(_ *cobra.Command, args []string) error {
-			if err := options.validate(args); err != nil {
+		RunE: func(cmd *cobra.Command, args []string) error {
+			if err := options.validate(cmd, args); err != nil {
 				return err
 			}
-			if err := options.run(args); err != nil {
-				fmt.Println(err.Error())
+			if err := options.run(cmd, args); err != nil {
+				fmt.Fprintln(cmd.OutOrStderr(), err.Error())
 			}
 
 			return nil
@@ -60,14 +60,14 @@ type describePlatformCommandOptions struct {
 	*RootCmdOptions
 }
 
-func (command *describePlatformCommandOptions) validate(args []string) error {
+func (command *describePlatformCommandOptions) validate(_ *cobra.Command, args []string) error {
 	if len(args) != 1 {
 		return errors.New("describe expects a platform name argument")
 	}
 	return nil
 }
 
-func (command *describePlatformCommandOptions) run(args []string) error {
+func (command *describePlatformCommandOptions) run(cmd *cobra.Command, args []string) error {
 	c, err := command.GetCmdClient()
 	if err != nil {
 		return err
@@ -80,28 +80,28 @@ func (command *describePlatformCommandOptions) run(args []string) error {
 	}
 
 	if err := c.Get(command.Context, platformKey, &platform); err == nil {
-		if desc, err := command.describeIntegrationPlatform(platform); err == nil {
-			fmt.Print(desc)
+		if desc, err := command.describeIntegrationPlatform(cmd, platform); err == nil {
+			fmt.Fprint(cmd.OutOrStdout(), desc)
 		} else {
-			fmt.Println(err)
+			fmt.Fprintln(cmd.ErrOrStderr(), err)
 		}
 	} else {
-		fmt.Printf("IntegrationPlatform '%s' does not exist.\n", args[0])
+		fmt.Fprintf(cmd.OutOrStdout(), "IntegrationPlatform '%s' does not exist.\n", args[0])
 	}
 
 	return nil
 }
 
-func (command *describePlatformCommandOptions) describeIntegrationPlatform(platform v1.IntegrationPlatform) (string, error) {
+func (command *describePlatformCommandOptions) describeIntegrationPlatform(cmd *cobra.Command, platform v1.IntegrationPlatform) (string, error) {
 	return indentedwriter.IndentedString(func(out io.Writer) error {
-		w := indentedwriter.NewWriter(out)
+		w := indentedwriter.NewWriter(cmd.OutOrStdout())
 		describeObjectMeta(w, platform.ObjectMeta)
-		w.Write(0, "Phase:\t%s\n", platform.Status.Phase)
-		w.Write(0, "Version:\t%s\n", platform.Status.Version)
-		w.Write(0, "Base Image:\t%s\n", platform.GetActualValue(getPlatformBaseImage))
-		w.Write(0, "Runtime Version:\t%s\n", platform.GetActualValue(getPlatformRuntimeVersion))
-		w.Write(0, "Local Repository:\t%s\n", platform.GetActualValue(getPlatformMavenLocalRepository))
-		w.Write(0, "Publish Strategy:\t%s\n", platform.GetActualValue(getPlatformPublishStrategy))
+		w.Writef(0, "Phase:\t%s\n", platform.Status.Phase)
+		w.Writef(0, "Version:\t%s\n", platform.Status.Version)
+		w.Writef(0, "Base Image:\t%s\n", platform.GetActualValue(getPlatformBaseImage))
+		w.Writef(0, "Runtime Version:\t%s\n", platform.GetActualValue(getPlatformRuntimeVersion))
+		w.Writef(0, "Local Repository:\t%s\n", platform.GetActualValue(getPlatformMavenLocalRepository))
+		w.Writef(0, "Publish Strategy:\t%s\n", platform.GetActualValue(getPlatformPublishStrategy))
 
 		return nil
 	})
