@@ -33,10 +33,11 @@ func newCmdLocalBuild(localCmdOptions *LocalCmdOptions) (*cobra.Command, *localB
 	}
 
 	cmd := cobra.Command{
-		Use:     "build [options]",
-		Short:   "Build integration images locally.",
-		Long:    `Build integration images locally for containerized integrations.`,
-		PreRunE: decode(&options),
+		Use:        "build [options]",
+		Short:      "Build integration images locally.",
+		Long:       `Build integration images locally for containerized integrations.`,
+		Deprecated: "it may be removed in future versions",
+		PreRunE:    decode(&options),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			if err := options.validate(cmd, args); err != nil {
 				return err
@@ -44,14 +45,12 @@ func newCmdLocalBuild(localCmdOptions *LocalCmdOptions) (*cobra.Command, *localB
 			if err := options.init(args); err != nil {
 				return err
 			}
-			if err := options.run(cmd, args); err != nil {
-				fmt.Fprintln(cmd.ErrOrStderr(), err.Error())
-			}
-			if err := options.deinit(); err != nil {
-				return err
-			}
-
-			return nil
+			defer func() {
+				if err := options.deinit(); err != nil {
+					fmt.Fprintln(cmd.ErrOrStderr(), err.Error())
+				}
+			}()
+			return options.run(cmd, args)
 		},
 		Annotations: map[string]string{
 			offlineCommandLabel: "true",
@@ -187,7 +186,7 @@ func (o *localBuildCmdOptions) run(cmd *cobra.Command, args []string) error {
 	routeFiles := args
 
 	if !o.BaseImage {
-		dependencies, err := local.GetDependencies(o.Context, args, o.Dependencies, o.MavenRepositories, true)
+		dependencies, err := local.GetDependencies(o.Context, cmd, args, o.Dependencies, o.MavenRepositories, true)
 		if err != nil {
 			return err
 		}
