@@ -18,9 +18,12 @@ limitations under the License.
 package integration
 
 import (
+	"encoding/json"
 	"reflect"
 	"testing"
 
+	camelv1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+
 	"github.com/stretchr/testify/assert"
 )
 
@@ -61,27 +64,37 @@ func TestNewHealthCheck(t *testing.T) {
 	`)
 	health, err := NewHealthCheck(body)
 	assert.NoError(t, err)
-	assert.Equal(t, HealthCheckStatusDown, health.Status)
+	assert.Equal(t, camelv1.HealthCheckStatusDown, health.Status)
 	assert.Len(t, health.Checks, 3)
 	assert.Equal(t, "camel-routes", health.Checks[0].Name)
-	assert.Equal(t, HealthCheckStatusDown, health.Checks[0].Status)
-	assert.True(t, reflect.DeepEqual(health.Checks[0].Data, map[string]interface{}{
+	assert.Equal(t, camelv1.HealthCheckStatusDown, health.Checks[0].Status)
+	assert.True(t, reflect.DeepEqual(raw2map(t, health.Checks[0].Data), map[string]interface{}{
 		"route.id":           "route1",
 		"route.context.name": "camel-1",
 		"route.status":       "Stopped",
 	}))
 	assert.Equal(t, "context", health.Checks[1].Name)
-	assert.Equal(t, HealthCheckStatusUp, health.Checks[1].Status)
-	assert.True(t, reflect.DeepEqual(health.Checks[1].Data, map[string]interface{}{
+	assert.Equal(t, camelv1.HealthCheckStatusUp, health.Checks[1].Status)
+	assert.True(t, reflect.DeepEqual(raw2map(t, health.Checks[1].Data), map[string]interface{}{
 		"context.name":    "camel-1",
 		"context.version": "3.16.0",
 		"context.status":  "Started",
 	}))
 	assert.Equal(t, "camel-consumers", health.Checks[2].Name)
-	assert.Equal(t, HealthCheckStatusDown, health.Checks[2].Status)
-	assert.True(t, reflect.DeepEqual(health.Checks[2].Data, map[string]interface{}{
+	assert.Equal(t, camelv1.HealthCheckStatusDown, health.Checks[2].Status)
+	assert.True(t, reflect.DeepEqual(raw2map(t, health.Checks[2].Data), map[string]interface{}{
 		"route.id":           "route1",
 		"route.context.name": "camel-1",
 		"route.status":       "Stopped",
 	}))
 }
+
+func raw2map(t *testing.T, in camelv1.RawMessage) map[string]interface{} {
+	t.Helper()
+	answer := make(map[string]interface{})
+
+	err := json.Unmarshal(in, &answer)
+	assert.Nil(t, err)
+
+	return answer
+}
