@@ -175,7 +175,7 @@ func TestIntegrationAutoGeneratedDeps(t *testing.T) {
 		},
 	}
 
-	for _, trait := range []Trait{newInitTrait(), newDependenciesTrait()} {
+	for _, trait := range []Trait{NewInitTrait(), newDependenciesTrait()} {
 		enabled, err := trait.Configure(e)
 		assert.Nil(t, err)
 		assert.True(t, enabled)
@@ -203,7 +203,7 @@ func TestIntegrationAutoGeneratedDeps(t *testing.T) {
 
 // in this test the language of the source is something unrelated to the
 // loader to test the order in which loader and language are taken into
-// account when dependencies are computed
+// account when dependencies are computed.
 func TestIntegrationCustomLoader(t *testing.T) {
 	catalog, err := camel.DefaultCatalog()
 	assert.Nil(t, err)
