@@ -19,9 +19,6 @@ package trait
 
 import (
 	"context"
-	"fmt"
-	"path/filepath"
-	"regexp"
 	"strconv"
 	"strings"
 	"sync"
@@ -38,9 +35,8 @@ import (
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/apimachinery/pkg/selection"
 	"k8s.io/client-go/discovery"
-	"k8s.io/client-go/discovery/cached/disk"
-	"k8s.io/client-go/discovery/cached/memory"
 	"k8s.io/utils/pointer"
+
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
@@ -49,13 +45,9 @@ import (
 )
 
 var (
-	toFileName = regexp.MustCompile(`[^(\w/\.)]`)
-
-	lock                  sync.Mutex
-	rateLimiter           = rate.NewLimiter(rate.Every(time.Minute), 1)
-	collectableGVKs       = make(map[schema.GroupVersionKind]struct{})
-	memoryCachedDiscovery discovery.CachedDiscoveryInterface
-	diskCachedDiscovery   discovery.CachedDiscoveryInterface
+	lock            sync.Mutex
+	rateLimiter     = rate.NewLimiter(rate.Every(time.Minute), 1)
+	collectableGVKs = make(map[schema.GroupVersionKind]struct{})
 )
 
 type gcTrait struct {
@@ -74,11 +66,6 @@ func (t *gcTrait) Configure(e *Environment) (bool, error) {
 		return false, nil
 	}
 
-	if t.DiscoveryCache == nil {
-		s := traitv1.MemoryDiscoveryCache
-		t.DiscoveryCache = &s
-	}
-
 	return e.IntegrationInPhase(v1.IntegrationPhaseInitialization) || e.IntegrationInRunningPhases(), nil
 }
 
@@ -190,11 +177,7 @@ func (t *gcTrait) getDeletableTypes(e *Environment) (map[schema.GroupVersionKind
 
 	// We rely on the discovery API to retrieve all the resources GVK,
 	// that results in an unbounded set that can impact garbage collection latency when scaling up.
-	discoveryClient, err := t.discoveryClient()
-	if err != nil {
-		return nil, err
-	}
-	resources, err := discoveryClient.ServerPreferredNamespacedResources()
+	resources, err := t.Client.Discovery().ServerPreferredNamespacedResources()
 	// Swallow group discovery errors, e.g., Knative serving exposes
 	// an aggregated API for custom.metrics.k8s.io that requires special
 	// authentication scheme while discovering preferred resources.
@@ -221,14 +204,23 @@ func (t *gcTrait) getDeletableTypes(e *Environment) (map[schema.GroupVersionKind
 	GVKs := make(map[schema.GroupVersionKind]struct{})
 	for _, APIResourceList := range APIResourceLists {
 		for _, resource := range APIResourceList.APIResources {
+			resourceGroup := resource.Group
+			if resourceGroup == "" {
+				// Empty implies the group of the containing resource list should be used
+				gv, err := schema.ParseGroupVersion(APIResourceList.GroupVersion)
+				if err != nil {
+					return nil, err
+				}
+				resourceGroup = gv.Group
+			}
 		rule:
 			for _, rule := range ssrr.Status.ResourceRules {
 				if !util.StringSliceContainsAnyOf(rule.Verbs, "delete", "*") {
 					continue
 				}
-				for _, group := range rule.APIGroups {
-					for _, name := range rule.Resources {
-						if (resource.Group == group || group == "*") && (resource.Name == name || name == "*") {
+				for _, ruleGroup := range rule.APIGroups {
+					for _, ruleResource := range rule.Resources {
+						if (resourceGroup == ruleGroup || ruleGroup == "*") && (resource.Name == ruleResource || ruleResource == "*") {
 							GVK := schema.FromAPIVersionAndKind(APIResourceList.GroupVersion, resource.Kind)
 							GVKs[GVK] = struct{}{}
 							break rule
@@ -242,31 +234,3 @@ func (t *gcTrait) getDeletableTypes(e *Environment) (map[schema.GroupVersionKind
 
 	return collectableGVKs, nil
 }
-
-func (t *gcTrait) discoveryClient() (discovery.DiscoveryInterface, error) {
-	switch *t.DiscoveryCache {
-	case traitv1.DiskDiscoveryCache:
-		if diskCachedDiscovery != nil {
-			return diskCachedDiscovery, nil
-		}
-		config := t.Client.GetConfig()
-		httpCacheDir := filepath.Join(mustHomeDir(), ".kube", "http-cache")
-		diskCacheDir := filepath.Join(mustHomeDir(), ".kube", "cache", "discovery", toHostDir(config.Host))
-		var err error
-		diskCachedDiscovery, err = disk.NewCachedDiscoveryClientForConfig(config, diskCacheDir, httpCacheDir, 10*time.Minute)
-		return diskCachedDiscovery, err
-
-	case traitv1.MemoryDiscoveryCache:
-		if memoryCachedDiscovery != nil {
-			return memoryCachedDiscovery, nil
-		}
-		memoryCachedDiscovery = memory.NewMemCacheClient(t.Client.Discovery())
-		return memoryCachedDiscovery, nil
-
-	case traitv1.DisabledDiscoveryCache, "":
-		return t.Client.Discovery(), nil
-
-	default:
-		return nil, fmt.Errorf("unsupported discovery cache type: %s", *t.DiscoveryCache)
-	}
-}
