@@ -25,34 +25,19 @@ import (
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/utils/pointer"
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
+	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/pkg/platform"
 	"github.com/apache/camel-k/pkg/util/kubernetes"
 	"github.com/apache/camel-k/pkg/util/openshift"
 )
 
-// The Pull Secret trait sets a pull secret on the pod,
-// to allow Kubernetes to retrieve the container image from an external registry.
-//
-// The pull secret can be specified manually or, in case you've configured authentication for an external container registry
-// on the `IntegrationPlatform`, the same secret is used to pull images.
-//
-// It's enabled by default whenever you configure authentication for an external container registry,
-// so it assumes that external registries are private.
-//
-// If your registry does not need authentication for pulling images, you can disable this trait.
-//
-// +camel-k:trait=pull-secret.
 type pullSecretTrait struct {
-	BaseTrait `property:",squash"`
-	// The pull secret name to set on the Pod. If left empty this is automatically taken from the `IntegrationPlatform` registry configuration.
-	SecretName string `property:"secret-name" json:"secretName,omitempty"`
-	// When using a global operator with a shared platform, this enables delegation of the `system:image-puller` cluster role on the operator namespace to the integration service account.
-	ImagePullerDelegation *bool `property:"image-puller-delegation" json:"imagePullerDelegation,omitempty"`
-	// Automatically configures the platform registry secret on the pod if it is of type `kubernetes.io/dockerconfigjson`.
-	Auto *bool `property:"auto" json:"auto,omitempty"`
+	BaseTrait
+	traitv1.PullSecretTrait `property:",squash"`
 }
 
 func newPullSecretTrait() Trait {
@@ -62,7 +47,7 @@ func newPullSecretTrait() Trait {
 }
 
 func (t *pullSecretTrait) Configure(e *Environment) (bool, error) {
-	if IsFalse(t.Enabled) {
+	if e.Integration == nil || !pointer.BoolDeref(t.Enabled, true) {
 		return false, nil
 	}
 
@@ -70,7 +55,7 @@ func (t *pullSecretTrait) Configure(e *Environment) (bool, error) {
 		return false, nil
 	}
 
-	if IsNilOrTrue(t.Auto) {
+	if pointer.BoolDeref(t.Auto, true) {
 		if t.SecretName == "" {
 			secret := e.Platform.Status.Build.Registry.Secret
 			if secret != "" {
@@ -85,22 +70,22 @@ func (t *pullSecretTrait) Configure(e *Environment) (bool, error) {
 			}
 		}
 		if t.ImagePullerDelegation == nil {
-			var isOpenshift bool
+			var isOpenShift bool
 			if t.Client != nil {
 				var err error
-				isOpenshift, err = openshift.IsOpenShift(t.Client)
+				isOpenShift, err = openshift.IsOpenShift(t.Client)
 				if err != nil {
 					return false, err
 				}
 			}
 			isOperatorGlobal := platform.IsCurrentOperatorGlobal()
 			isKitExternal := e.Integration.GetIntegrationKitNamespace(e.Platform) != e.Integration.Namespace
-			needsDelegation := isOpenshift && isOperatorGlobal && isKitExternal
+			needsDelegation := isOpenShift && isOperatorGlobal && isKitExternal
 			t.ImagePullerDelegation = &needsDelegation
 		}
 	}
 
-	return t.SecretName != "" || IsTrue(t.ImagePullerDelegation), nil
+	return t.SecretName != "" || pointer.BoolDeref(t.ImagePullerDelegation, false), nil
 }
 
 func (t *pullSecretTrait) Apply(e *Environment) error {
@@ -111,7 +96,7 @@ func (t *pullSecretTrait) Apply(e *Environment) error {
 			})
 		})
 	}
-	if IsTrue(t.ImagePullerDelegation) {
+	if pointer.BoolDeref(t.ImagePullerDelegation, false) {
 		if err := t.delegateImagePuller(e); err != nil {
 			return err
 		}
@@ -124,7 +109,7 @@ func (t *pullSecretTrait) delegateImagePuller(e *Environment) error {
 	// Applying the RoleBinding directly because it's a resource in the operator namespace
 	// (different from the integration namespace when delegation is enabled).
 	rb := t.newImagePullerRoleBinding(e)
-	if err := kubernetes.ReplaceResource(e.Ctx, e.Client, rb); err != nil {
+	if _, err := kubernetes.ReplaceResource(e.Ctx, e.Client, rb); err != nil {
 		return errors.Wrap(err, "error during the creation of the system:image-puller delegating role binding")
 	}
 	return nil
