@@ -26,21 +26,20 @@ import (
 
 	base64 "encoding/base64"
 
+	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/pkg/platform"
 	"github.com/apache/camel-k/pkg/util/kubernetes"
 	"github.com/apache/camel-k/pkg/util/registry"
-	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 
-	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	corev1 "k8s.io/api/core/v1"
+	"k8s.io/utils/pointer"
+	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
-// The Registry trait sets up Maven to use the Image registry
-// as a Maven repository.
-//
-// +camel-k:trait=registry.
 type registryTrait struct {
-	BaseTrait `property:",squash"`
+	BaseTrait
+	traitv1.RegistryTrait `property:",squash"`
 }
 
 func newRegistryTrait() Trait {
@@ -56,7 +55,7 @@ func (t *registryTrait) InfluencesKit() bool {
 
 func (t *registryTrait) Configure(e *Environment) (bool, error) {
 	// disabled by default
-	if IsNilOrFalse(t.Enabled) {
+	if e.IntegrationKit == nil || !pointer.BoolDeref(t.Enabled, false) {
 		return false, nil
 	}
 
@@ -64,7 +63,7 @@ func (t *registryTrait) Configure(e *Environment) (bool, error) {
 }
 
 func (t *registryTrait) Apply(e *Environment) error {
-	registryAddress := e.Platform.Spec.Build.Registry.Address
+	registryAddress := e.Platform.Status.Build.Registry.Address
 	if registryAddress == "" && e.Platform.Status.Cluster == v1.IntegrationPlatformClusterOpenShift {
 		registryAddress = "image-registry.openshift-image-registry.svc:5000"
 	}
@@ -72,8 +71,8 @@ func (t *registryTrait) Apply(e *Environment) error {
 		return errors.New("could not figure out Image Registry URL, please set it manually")
 	}
 	build := getBuilderTask(e.BuildTasks)
-	registryCa := e.Platform.Spec.Build.Registry.CA
-	registrySecret := e.Platform.Spec.Build.Registry.Secret
+	registryCa := e.Platform.Status.Build.Registry.CA
+	registrySecret := e.Platform.Status.Build.Registry.Secret
 	if e.Platform.Status.Cluster == v1.IntegrationPlatformClusterOpenShift {
 		if registryCa == "" {
 			ca, err := getOpenShiftImageRegistryCA(e)
@@ -108,7 +107,7 @@ func (t *registryTrait) Apply(e *Environment) error {
 }
 
 func addRegistryAndExtensionToMaven(registryAddress string, build *v1.BuilderTask, platform *v1.IntegrationPlatform) {
-	organization := platform.Spec.Build.Registry.Organization
+	organization := platform.Status.Build.Registry.Organization
 	if organization == "" {
 		organization = platform.Namespace
 	}
