@@ -40,7 +40,7 @@ type Binding struct {
 	// Step is to support complex mapping such as Camel's EIPs
 	Step map[string]interface{}
 	// Traits is a partial trait specification that should be merged into the integration
-	Traits map[string]v1.TraitSpec
+	Traits v1.Traits
 	// ApplicationProperties contain properties that should be set on the integration for the binding to work
 	ApplicationProperties map[string]string
 }
@@ -55,6 +55,7 @@ type BindingProvider interface {
 	Order() int
 }
 
+// nolint: containedctx
 type BindingContext struct {
 	Ctx       context.Context
 	Client    client.Client
