@@ -18,12 +18,14 @@ limitations under the License.
 package bindings
 
 import (
-	"encoding/json"
 	"net/url"
 	"strings"
 
+	"k8s.io/utils/pointer"
+
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	knativeapis "github.com/apache/camel-k/pkg/apis/camel/v1/knative"
+	traitv1 "github.com/apache/camel-k/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
 	"github.com/apache/camel-k/pkg/util/uri"
 )
@@ -35,7 +37,7 @@ func (k KnativeURIBindingProvider) ID() string {
 	return "knative-uri"
 }
 
-func (k KnativeURIBindingProvider) Translate(ctx BindingContext, endpointType v1alpha1.EndpointType, e v1alpha1.Endpoint) (*Binding, error) {
+func (k KnativeURIBindingProvider) Translate(ctx BindingContext, endpointCtx EndpointContext, e v1alpha1.Endpoint) (*Binding, error) {
 	if e.URI == nil {
 		// works only on uris
 		return nil, nil
@@ -48,12 +50,11 @@ func (k KnativeURIBindingProvider) Translate(ctx BindingContext, endpointType v1
 		// only translates http/https uri to Knative calls
 		return nil, nil
 	}
-	if endpointType == v1alpha1.EndpointTypeSource {
+	if endpointCtx.Type == v1alpha1.EndpointTypeSource {
 		// HTTP/HTTPS uri are translated to Knative endpoints only when used as sinks
 		return nil, nil
 	}
 
-	knativeConfig := make(map[string]interface{})
 	originalURI, err := url.Parse(*e.URI)
 	if err != nil {
 		return nil, err
@@ -71,12 +72,6 @@ func (k KnativeURIBindingProvider) Translate(ctx BindingContext, endpointType v1
 	if err != nil {
 		return nil, err
 	}
-	knativeConfig["configuration"] = config
-	knativeConfig["sinkBinding"] = false
-	knativeConfigJSON, err := json.Marshal(knativeConfig)
-	if err != nil {
-		return nil, err
-	}
 
 	// Rewrite URI to match the service definition
 	serviceURI := "knative:endpoint/sink"
@@ -88,11 +83,10 @@ func (k KnativeURIBindingProvider) Translate(ctx BindingContext, endpointType v1
 
 	return &Binding{
 		URI: serviceURI,
-		Traits: map[string]v1.TraitSpec{
-			"knative": {
-				Configuration: v1.TraitConfiguration{
-					RawMessage: knativeConfigJSON,
-				},
+		Traits: v1.Traits{
+			Knative: &traitv1.KnativeTrait{
+				Configuration: config,
+				SinkBinding:   pointer.Bool(false),
 			},
 		},
 	}, nil
