@@ -19,6 +19,7 @@ package knative
 
 import (
 	"context"
+	"encoding/json"
 	"fmt"
 	"net/url"
 
@@ -27,6 +28,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime/schema"
+	"k8s.io/apimachinery/pkg/types"
 	"knative.dev/pkg/apis"
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
@@ -141,7 +143,7 @@ func CreateSinkBinding(source corev1.ObjectReference, target corev1.ObjectRefere
 	}
 }
 
-// GetAddressableReference looks up the resource among all given types and returns an object reference to it
+// GetAddressableReference looks up the resource among all given types and returns an object reference to it.
 func GetAddressableReference(ctx context.Context, c client.Client,
 	possibleReferences []corev1.ObjectReference, namespace string, name string) (*corev1.ObjectReference, error) {
 
@@ -160,7 +162,7 @@ func GetAddressableReference(ctx context.Context, c client.Client,
 	return nil, k8serrors.NewNotFound(schema.GroupResource{}, name)
 }
 
-// GetSinkURL returns the sink as *url.URL
+// GetSinkURL returns the sink as *url.URL.
 func GetSinkURL(ctx context.Context, c client.Client, sink *corev1.ObjectReference, namespace string) (*url.URL, error) {
 	res, err := getSinkURI(ctx, c, sink, namespace)
 	if err != nil {
@@ -206,3 +208,35 @@ func getSinkURI(ctx context.Context, c client.Client, sink *corev1.ObjectReferen
 	}
 	return addressURL.String(), nil
 }
+
+// EnableKnativeBindInNamespace sets the "bindings.knative.dev/include=true" label to the namespace, only
+// if there aren't any of these labels bindings.knative.dev/include bindings.knative.dev/exclude in the namespace
+// Returns true if the label was set in the namespace
+// https://knative.dev/docs/eventing/custom-event-source/sinkbinding/create-a-sinkbinding
+func EnableKnativeBindInNamespace(ctx context.Context, client client.Client, namespace string) (bool, error) {
+	ns, err := client.CoreV1().Namespaces().Get(ctx, namespace, metav1.GetOptions{})
+	if err != nil {
+		return false, err
+	}
+
+	// if there are sinkbinding labels in the namespace, camel-k-operator respects it and doesn't proceed
+	sinkbindingLabelsExists := ns.Labels["bindings.knative.dev/include"] != "" || ns.Labels["bindings.knative.dev/exclude"] != ""
+	if sinkbindingLabelsExists {
+		return false, nil
+	}
+
+	var jsonLabelPatch = map[string]interface{}{
+		"metadata": map[string]interface{}{
+			"labels": map[string]string{"bindings.knative.dev/include": "true"},
+		},
+	}
+	patch, err := json.Marshal(jsonLabelPatch)
+	if err != nil {
+		return false, err
+	}
+	_, err = client.CoreV1().Namespaces().Patch(ctx, namespace, types.MergePatchType, patch, metav1.PatchOptions{})
+	if err != nil {
+		return false, err
+	}
+	return true, nil
+}
