@@ -207,6 +207,12 @@ func InspectorForLanguage(catalog *camel.RuntimeCatalog, language v1.Language) I
 				catalog: catalog,
 			},
 		}
+	case v1.LanguageJavaShell:
+		return &JavaSourceInspector{
+			baseInspector: baseInspector{
+				catalog: catalog,
+			},
+		}
 	}
 	return &baseInspector{}
 }
@@ -336,7 +342,14 @@ func (i *baseInspector) discoverKamelets(meta *Metadata) {
 }
 
 func (i *baseInspector) addDependencies(uri string, meta *Metadata, consumer bool) error {
+	if !i.catalog.IsResolvable(uri) {
+		// ignore dependencies for given URI as it is not resolvable in this state
+		// (e.g. using a property placeholder such as {{url} or {{scheme}}:{{resource}})
+		return nil
+	}
+
 	candidateComp, scheme := i.catalog.DecodeComponent(uri)
+
 	if candidateComp == nil || scheme == nil {
 		return fmt.Errorf("component not found for uri %q in camel catalog runtime version %s",
 			uri, i.catalog.GetRuntimeVersion())
