@@ -42,21 +42,15 @@ func (i JavaScriptInspector) Extract(source v1.SourceSpec, meta *Metadata) error
 		doubleQuotedToD,
 		singleQuotedToF,
 		doubleQuotedToF,
+		singleQuotedWireTap,
+		doubleQuotedWireTap,
 	)
-
-	meta.FromURIs = append(meta.FromURIs, from...)
-	meta.ToURIs = append(meta.ToURIs, to...)
-
-	i.discoverCapabilities(source, meta)
-	i.discoverDependencies(source, meta)
+	kameletEips := util.FindAllDistinctStringSubmatch(
+		source.Content,
+		singleQuotedKameletEip,
+		doubleQuotedKameletEip)
 
 	hasRest := restRegexp.MatchString(source.Content)
-	if hasRest {
-		meta.RequiredCapabilities.Add(v1.CapabilityRest)
-	}
 
-	meta.ExposesHTTPServices = hasRest || i.containsHTTPURIs(meta.FromURIs)
-	meta.PassiveEndpoints = i.hasOnlyPassiveEndpoints(meta.FromURIs)
-
-	return nil
+	return i.extract(source, meta, from, to, kameletEips, hasRest)
 }
