@@ -18,9 +18,13 @@ limitations under the License.
 package util
 
 import (
+	"fmt"
+	"os"
+	"path/filepath"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestStringContainsPrefix(t *testing.T) {
@@ -32,5 +36,27 @@ func TestStringContainsPrefix(t *testing.T) {
 func TestRandomString(t *testing.T) {
 	assert.Equal(t, 10, len(RandomString(10)))
 	assert.NotEqual(t, RandomString(10), RandomString(10))
+}
 
+func TestSubstringFrom(t *testing.T) {
+	assert.Equal(t, "/bbb/ccc", SubstringFrom("aaa/bbb/ccc", "/"))
+	assert.Empty(t, SubstringFrom("aaa/bbb/ccc", "?"))
+}
+
+func TestSubstringBefore(t *testing.T) {
+	assert.Equal(t, "aaa/bbb", SubstringBefore("aaa/bbb/ccc", "/"))
+	assert.Equal(t, "aaa/bbb", SubstringBefore("aaa/bbb?ccc=ddd", "?"))
+	assert.Empty(t, SubstringBefore("aaa/bbb/ccc", "?"))
+}
+
+func TestCopyDir(t *testing.T) {
+	srcDir := "../../install"
+	tmpDir, err := os.MkdirTemp("", "TestCopyDir-*")
+	defer os.RemoveAll(tmpDir)
+	destDir := filepath.Join(tmpDir, "install")
+
+	require.NoError(t, err)
+	fmt.Println(destDir)
+	err = CopyDir(srcDir, destDir)
+	assert.NoError(t, err)
 }
